==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QTimerEvent_shell.cpp <==
#include "QTimerEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QTimerEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTimerEvent")
    QTimerEvent *_ptr = reinterpret_cast<QTimerEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTimerEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTimerEvent_shell) ); }

jmethodID QTimerEvent_shell::__shell_javaMethod(int pos) const { return QTimerEvent_shell::__shell()->javaMethod(typeid(QTimerEvent), pos); }

// emitting (writeShellConstructor)
QTimerEvent_shell::QTimerEvent_shell(const QTimerEvent& arg__1)
    : QTimerEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTimerEvent::QTimerEvent_shell(const QTimerEvent& arg__1)", QTimerEvent_shell::__shell())
    QTimerEvent_shell::__shell()->constructed(typeid(QTimerEvent));
}

QTimerEvent_shell::QTimerEvent_shell(int timerId0)
    : QTimerEvent(timerId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTimerEvent::QTimerEvent_shell(int timerId0)", QTimerEvent_shell::__shell())
    QTimerEvent_shell::__shell()->constructed(typeid(QTimerEvent));
}

// emitting (writeShellDestructor)
QTimerEvent_shell::~QTimerEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTimerEvent::~QTimerEvent()", QTimerEvent_shell::__shell())
    QTimerEvent_shell::__shell()->destructed(typeid(QTimerEvent));
}

void QTimerEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTimerEvent_shell*>(ptr)->QTimerEvent_shell::__shell()->tryDeleteShell(typeid(QTimerEvent));
}

// emitting Virtual overrides (virtualFunctions)
QTimerEvent* QTimerEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QTimerEvent::clone()const", QTimerEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTimerEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QTimerEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QTimerEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QTimerEvent_shell::__shell()->warnForMethod("QTimerEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTimerEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QTimerEvent::clone();
        }
    }else{
        return QTimerEvent::clone();
    }
}

void QTimerEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QTimerEvent::", QTimerEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QTimerEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QTimerEvent_shell::__shell()->warnForMethod("QTimerEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTimerEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QTimerEvent_access::__qt_assign_cref_QTimerEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QTimerEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QTimerEvent>(__jni_env, other0);
    QTimerEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QTimerEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QTimerEvent* __qt_return_value = QTimerEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QTimerEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QTimerEvent(QTimerEvent)
void __qt_construct_QTimerEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTimerEvent(QTimerEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QTimerEvent& __qt_arg__1 = qtjambi_cast<const QTimerEvent& >(__jni_env, arg__1);
    QTimerEvent *__qt_this = new(__qtjambi_ptr) QTimerEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QTimerEvent(int)
void __qt_construct_QTimerEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTimerEvent(int)")
    jint timerId0 = __java_arguments[0].i;
    Q_UNUSED(timerId0)
    QTimerEvent *__qt_this = new(__qtjambi_ptr) QTimerEvent_shell(static_cast<int>(timerId0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTimerEvent_shell
void __qt_destruct_QTimerEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTimerEvent")
    reinterpret_cast<QTimerEvent_shell*>(ptr)->~QTimerEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTimerEvent::QTimerEvent(QTimerEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_initialize_1native__Lio_qt_core_QTimerEvent_2Lio_qt_core_QTimerEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimerEvent::QTimerEvent(QTimerEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimerEvent_0, sizeof(QTimerEvent_shell), typeid(QTimerEvent), true, &deleter_QTimerEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTimerEvent::QTimerEvent(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_initialize_1native__Lio_qt_core_QTimerEvent_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint timerId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimerEvent::QTimerEvent(int)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.i = timerId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimerEvent_1, sizeof(QTimerEvent_shell), typeid(QTimerEvent), true, &deleter_QTimerEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTimerEvent::operator=(QTimerEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_assign_1native_1cref_1QTimerEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTimerEvent::operator=(QTimerEvent)", __qt_this)
        static_cast<QTimerEvent_access*>(__qt_this)->__qt_assign_cref_QTimerEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTimerEvent::timerId()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_timerId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTimerEvent::timerId()const", __qt_this)
        __java_return_value = __qt_this->timerId();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTimerEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTimerEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QTimerEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QTimerEvent_access::setTimerId_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timerId0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    this->QTimerEvent::id = static_cast<int>(timerId0);
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_setTimerId_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timerId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QTimerEvent_access*>(__qt_this)->setTimerId_int(__jni_env, __this_nativeId, timerId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTimerEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTimerEvent>("QTimerEvent", "io/qt/core/QTimerEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QTimerEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QTimerEvent, {
        ConstructorInfo(&__qt_construct_QTimerEvent_0, "Lio/qt/core/QTimerEvent;")
       ,ConstructorInfo(&__qt_construct_QTimerEvent_1, "I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTimerEvent);
    registerSizeOfShell(typeId, sizeof(QTimerEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QTimerEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QTimerEvent_shell.cpp <==
#include "QTimerEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QTimerEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTimerEvent")
    QTimerEvent *_ptr = reinterpret_cast<QTimerEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QTimerEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QTimerEvent_shell) ); }

jmethodID QTimerEvent_shell::__shell_javaMethod(int pos) const { return QTimerEvent_shell::__shell()->javaMethod(typeid(QTimerEvent), pos); }

// emitting (writeShellConstructor)
QTimerEvent_shell::QTimerEvent_shell(const QTimerEvent& arg__1)
    : QTimerEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTimerEvent::QTimerEvent_shell(const QTimerEvent& arg__1)", QTimerEvent_shell::__shell())
    QTimerEvent_shell::__shell()->constructed(typeid(QTimerEvent));
}

QTimerEvent_shell::QTimerEvent_shell(int timerId0)
    : QTimerEvent(timerId0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QTimerEvent::QTimerEvent_shell(int timerId0)", QTimerEvent_shell::__shell())
    QTimerEvent_shell::__shell()->constructed(typeid(QTimerEvent));
}

// emitting (writeShellDestructor)
QTimerEvent_shell::~QTimerEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QTimerEvent::~QTimerEvent()", QTimerEvent_shell::__shell())
    QTimerEvent_shell::__shell()->destructed(typeid(QTimerEvent));
}

void QTimerEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QTimerEvent_shell*>(ptr)->QTimerEvent_shell::__shell()->tryDeleteShell(typeid(QTimerEvent));
}

// emitting Virtual overrides (virtualFunctions)
QTimerEvent* QTimerEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QTimerEvent::clone()const", QTimerEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTimerEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QTimerEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QTimerEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QTimerEvent_shell::__shell()->warnForMethod("QTimerEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTimerEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QTimerEvent::clone();
        }
    }else{
        return QTimerEvent::clone();
    }
}

void QTimerEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QTimerEvent::", QTimerEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QTimerEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QTimerEvent_shell::__shell()->warnForMethod("QTimerEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QTimerEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QTimerEvent_access::__qt_assign_cref_QTimerEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QTimerEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QTimerEvent>(__jni_env, other0);
    QTimerEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QTimerEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QTimerEvent* __qt_return_value = QTimerEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QTimerEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QTimerEvent(QTimerEvent)
void __qt_construct_QTimerEvent_cref_QTimerEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTimerEvent(QTimerEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QTimerEvent& __qt_arg__1 = qtjambi_cast<const QTimerEvent& >(__jni_env, arg__1);
    QTimerEvent *__qt_this = new(__qtjambi_ptr) QTimerEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTimerEvent::QTimerEvent(QTimerEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_initialize_1native__Lio_qt_core_QTimerEvent_2Lio_qt_core_QTimerEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimerEvent::QTimerEvent(QTimerEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimerEvent_cref_QTimerEvent, sizeof(QTimerEvent_shell), typeid(QTimerEvent), true, &deleter_QTimerEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QTimerEvent(int)
void __qt_construct_QTimerEvent_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QTimerEvent(int)")
    jint timerId0 = __java_arguments[0].i;
    Q_UNUSED(timerId0)
    QTimerEvent *__qt_this = new(__qtjambi_ptr) QTimerEvent_shell(static_cast<int>(timerId0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTimerEvent::QTimerEvent(int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_initialize_1native__Lio_qt_core_QTimerEvent_2I)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint timerId0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimerEvent::QTimerEvent(int)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.i = timerId0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimerEvent_int, sizeof(QTimerEvent_shell), typeid(QTimerEvent), true, &deleter_QTimerEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTimerEvent_shell
void __qt_destruct_QTimerEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTimerEvent")
    reinterpret_cast<QTimerEvent_shell*>(ptr)->~QTimerEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTimerEvent::operator=(QTimerEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_assign_1native_1cref_1QTimerEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTimerEvent::operator=(QTimerEvent)", __qt_this)
        static_cast<QTimerEvent_access*>(__qt_this)->__qt_assign_cref_QTimerEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QTimerEvent::timerId()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_timerId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTimerEvent::timerId()const", __qt_this)
        __java_return_value = __qt_this->timerId();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTimerEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTimerEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QTimerEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QTimerEvent_access::setTimerId_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timerId0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    this->QTimerEvent::id = static_cast<int>(timerId0);
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimerEvent_setTimerId_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint timerId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimerEvent *__qt_this = QtJambiAPI::objectFromNativeId<QTimerEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QTimerEvent_access*>(__qt_this)->setTimerId_int(__jni_env, __this_nativeId, timerId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QTimerEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QTimerEvent>("QTimerEvent", "io/qt/core/QTimerEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/core/QTimerEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QTimerEvent, {
        ConstructorInfo(&__qt_construct_QTimerEvent_cref_QTimerEvent, "Lio/qt/core/QTimerEvent;")
       ,ConstructorInfo(&__qt_construct_QTimerEvent_int, "I")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTimerEvent);
    registerSizeOfShell(typeId, sizeof(QTimerEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QTimerEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
